@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "flymake-bashate" "1.0.4"
+(define-package "flymake-bashate" "20260114.1535"
   "A Flymake backend for bashate, a Bash scripts style checker."
   '((flymake-quickdef "1.0.0")
     (emacs            "27.1"))
   :url "https://github.com/jamescherti/flymake-bashate.el"
-  :commit "c599d3c15c6f174a54c1f3d0081311758e682089"
-  :revdesc "1.0.4-0-gc599d3c15c6f"
+  :commit "91a687fd2c10c09e3509ea32e91209877affe379"
+  :revdesc "91a687fd2c10"
   :keywords '("tools"))
